:tocdepth: 2

=======================
Shared File Systems API
=======================

.. rest_expand_all::

.. include:: versions.inc
.. include:: extensions.inc
.. include:: limits.inc
.. include:: shares.inc
.. include:: share-export-locations.inc
.. include:: share-metadata.inc
.. include:: share-actions.inc
.. include:: snapshots.inc
.. include:: snapshot-instances.inc
.. include:: share-networks.inc
.. include:: security-services.inc
.. include:: share-servers.inc
.. include:: share-instances.inc
.. include:: share-instance-export-locations.inc
.. include:: share-types.inc
.. include:: scheduler-stats.inc
.. include:: services.inc
.. include:: availability-zones.inc
.. include:: os-share-manage.inc
.. include:: quota-sets.inc
.. include:: quota-classes.inc
.. include:: user-messages.inc
.. include:: share-access-rules.inc
.. include:: share-access-rule-metadata.inc

======================================
Shared File Systems API (EXPERIMENTAL)
======================================

.. rest_expand_all::

.. include:: experimental.inc
.. include:: share-migration.inc
.. include:: share-replicas.inc
.. include:: share-replica-export-locations.inc
.. include:: share-groups.inc
.. include:: share-group-types.inc
.. include:: share-group-snapshots.inc
